#!/usr/bin/python
#
# Copyright (C) 2010, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-iso-testing.
#
# ubuntu-iso-testing is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-iso-testing is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-iso-testing.  If not, see
# <http://www.gnu.org/licenses/>.
#

import jinja2
import logging
import optparse
import os
import sys

logging.basicConfig(level=logging.DEBUG)

usage = "usage: %prog [options] template"
parser = optparse.OptionParser(usage=usage)
parser.add_option("-d", "--debug", dest="debug", action="store_true",
                  default=False,
                  help="enable debugging")
parser.add_option("-t", "--templates", dest="template_dir",
                  help="Location of templates to use")
parser.add_option("-p", "--proxy", dest="proxy",
                  help="Proxy server to use during install")


(options, args) = parser.parse_args()
if options.debug:
    logging.basicConfig(level=logging.DEBUG)
else:
    logging.basicConfig(level=logging.INFO)

logging.debug("Options: %s" % (options))
logging.debug("Arguments: %s" % (args))

if len(args) == 0:
    logging.error("Need template preseed as a parameter")
    parser.print_help()
    sys.exit(1)

TMPL_DIR = os.path.abspath(options.template_dir)

# Load the templates
templates = jinja2.Environment(loader=jinja2.FileSystemLoader(TMPL_DIR))
template = args[0]
tmpl = templates.get_template("%s" % template)
ctxt = {"proxyurl": options.proxy}

# Print to STDOUT
print tmpl.render(ctxt)
