# Run a scenario in UTAH
#
# The way to use the base script is as follows:
# - source it from a scenario script
# - echo the CMD environment variable
#   (together with any other option required to run the scenario)
#
# The scenario script will be used in the jenkins jobs to launch a runlist with
# all the command line arguments needed.

# Set default values to enviroment variables needed to call run_utah_tests.py
set_environment()
{
    BRANCH_DIR=${BRANCH_DIR:-lp:ubuntu-test-cases/server}

    SCRIPT=$(basename $0)
    SCRIPT_NAME=${SCRIPT%.*}
    PRESEED=${BRANCH_DIR}/preseeds/${SCRIPT_NAME}.preseed
    RUNLIST=${BRANCH_DIR}/runlists/${SCRIPT_NAME}.run
}

# Print usage string
usage()
{
    cat <<EOF
usage: $(basename $0) -i IMAGE

Run server default scenario using default parameters

options:
    -h               Show this help and exit
    -i IMAGE         Path/URL to image to be used
EOF
}

# Parse arguments or print usage string on error
parse_args()
{
    while getopts :i: OPTION; do
        case $OPTION in
            i)
                IMAGE=$OPTARG
                ;;
            ?)
                usage
                exit
                ;;
        esac
    done

    if [ -z "$IMAGE" ]; then
        usage
        exit
    fi

    if [ -z "$PRESEED" ]; then
        echo "PRESEED environment variable not found"
        exit
    fi

    if [ -z "$RUNLIST" ]; then
        echo "RUNLIST environment variable not found"
        exit
    fi
}

# Set CMD enviroment variable with the command line needed to run_utah_tests.py
set_command()
{
    CMD="run_utah_tests.py -i $IMAGE -p $PRESEED $RUNLIST"
}

set_environment
parse_args "$@"
set_command
