import logging
import subprocess
import unittest
import urllib2

logging.basicConfig(level=logging.INFO)


class CephDaemonTest(unittest.TestCase):
    def testCephHealth(self):
        cmd = ["ceph", "health"]
        logging.debug("Cmd: %s" % (cmd))
        output = subprocess.Popen(cmd, stdout=subprocess.PIPE).communicate()[0]
        logging.debug("Cmd output: %s" % (output))
        self.assertTrue("HEALTH_OK" in output,
                        "Ceph health not ok - output: %s" % output)

    def testCephVersion(self):
        cmd = ["ceph", "-v"]
        logging.debug("Cmd: %s" % (cmd))
        output = subprocess.Popen(cmd, stdout=subprocess.PIPE).communicate()[0]
        logging.debug("Cmd output: %s" % (output))
        self.assertTrue("(commit:)" not in output,
                        "ceph -v output broken: %s" % output)

    def testCephMon(self):
        cmd = ["pgrep", "ceph-mon"]
        logging.debug("Cmd: %s" % (cmd))
        output = subprocess.Popen(cmd, stdout=subprocess.PIPE).communicate()[0]
        logging.debug("Cmd output: %s", output)
        self.assertTrue(output.count('\n') == 1,
                        "Ceph Mon Daemon not running or to many daemons "
                        "running: %s" % output)

    def testCephOsd(self):
        cmd = ["pgrep", "ceph-osd"]
        logging.debug("Cmd: %s" % (cmd))
        output = subprocess.Popen(cmd, stdout=subprocess.PIPE).communicate()[0]
        logging.debug("Cmd output: %s", output)
        self.assertTrue(output.count('\n') == 2,
                        "Ceph OSD Daemons not running or incorrect number of "
                        "daemons running: %s" % output)

    @unittest.skip("Temporarly disabled as currently fails in the lab")
    def testCephRadosGateway(self):
        cmd = ["pgrep", "radosgw"]
        logging.debug("Cmd: %s" % (cmd))
        output = subprocess.Popen(cmd, stdout=subprocess.PIPE).communicate()[0]
        logging.debug("Cmd output: %s", output)
        self.assertTrue(output.count('\n') == 1,
                        "Ceph Rados Gateway Daemon not running or to many "
                        "daemons running: %s" % output)

    @unittest.skip("Temporarly disabled as currently fails in the lab")
    def testCephRadosGatewayApache(self):
        local_host_url = 'http://localhost:80'
        try:
            fh = urllib2.urlopen(local_host_url)
        except urllib2.HTTPError, e:
            logging.error("Failed to open localhost, '%s' error", e)
            self.fail("Failed to connect to the localhost")
        output = fh.read()
        logging.debug("Check if \'ListAllMyBucketsResult\' is present in: %s" %
                      (output))
        self.assertTrue('ListAllMyBucketsResult' in output,
                        output)


if __name__ == '__main__':
    unittest.main()
