#!/bin/bash

set -e

echo "Testing creation of rados block device"
rbd create utah-dev-01 --size 20

echo "Checking its been created OK"
rbd ls | grep utah-dev-01

echo "Check some information about the image"
rbd --image utah-dev-01 info | grep "size 20480 KB"

echo "Resize the image"
rbd resize --image utah-dev-01 --size 40

echo "Check resize worked OK"
rbd --image utah-dev-01 info | grep "size 40960 KB"

echo "Configuring to mount image"
modprobe rbd
rbd map utah-dev-01 --name client.admin

echo "Check that image mapped OK"
rbd showmapped | grep utah-dev-01

echo "Mounting device and checking writable"
device=`rbd showmapped | grep utah-dev-01 | awk '{ print $5 }'`
mkdir -p /mnt/utah
mkfs -t ext4 $device
mount $device /mnt/utah

echo "Check writable"
echo "Hello Ceph" | tee /mnt/utah/test

echo "Unmount and unmap device"
umount /mnt/utah
rbd unmap $device

echo "Remove the image"
rbd rm utah-dev-01


