#!/bin/bash

set -ex

HOSTNAME=`hostname`
IPADDR=`hostname -i`

apt-get update
apt-get -y install ceph radosgw libapache2-mod-fastcgi rest-bench libs3-2 apache2

echo "Creating all-in-one ceph configuration"
tee /etc/ceph/ceph.conf << EOF
[osd]
        osd journal size = 1000
        filestore xattr use omap = true

[mon.a]
        host = ${HOSTNAME}
        mon addr = ${IPADDR}:6789

[osd.0]
        host = ${HOSTNAME}

[osd.1]
        host = ${HOSTNAME}

[client.radosgw.gateway]
        host = ${HOSTNAME}
        keyring = /etc/ceph/keyring.rados.gateway
        rgw socket path = /tmp/radosgw.sock
        log file = /var/log/ceph/radosgw.log
EOF

echo "Creating apache configuration for radosgw"
tee /etc/apache2/sites-available/rgw << EOF
<IfModule mod_fastcgi.c>
        FastCgiExternalServer /var/www/s3gw.fcgi -socket /tmp/radosgw.sock
</IfModule>

<VirtualHost *:80>
        ServerName ${HOSTNAME}
        ServerAdmin ceph@ubuntu.com
        DocumentRoot /var/www
        RewriteEngine On
        RewriteRule ^/([a-zA-Z0-9-_.]*)([/]?.*) /s3gw.fcgi?page=$1&params=$2&%{QUERY_STRING} [E=HTTP_AUTHORIZATION:%{HTTP:Authorization},L]
        <IfModule mod_fastcgi.c>
                <Directory /var/www>
                        Options +ExecCGI
                        AllowOverride All
                        SetHandler fastcgi-script
                        Order allow,deny
                        Allow from all
                        AuthBasicAuthoritative Off
                </Directory>
        </IfModule>
        AllowEncodedSlashes On
        ErrorLog /var/log/apache2/error.log
        CustomLog /var/log/apache2/access.log combined
        ServerSignature Off
</VirtualHost>
EOF
echo "Configuring apache"
a2dissite default || true
a2ensite rgw || true
a2enmod fastcgi || true
a2enmod rewrite || true
service apache2 restart

echo "Creating s3 gateway wrapper"
tee /var/www/s3gw.fcgi << EOF
#!/bin/sh
exec /usr/bin/radosgw -c /etc/ceph/ceph.conf -n client.radosgw.gateway
EOF
chmod a+x /var/www/s3gw.fcgi

echo "Initializing ceph"
mkdir -p /var/lib/ceph/osd/ceph-0
mkdir -p /var/lib/ceph/osd/ceph-1
mkdir -p /var/lib/ceph/mon/ceph-a
mkdir -p /var/lib/ceph/mds/ceph-a

(
    cd /etc/ceph
    mkcephfs -a -c /etc/ceph/ceph.conf -k ceph.keyring
)

echo "Starting ceph"
service ceph start

echo "Configuring rados gateway"
ceph-authtool --create-keyring /etc/ceph/keyring.rados.gateway
chmod +r /etc/ceph/keyring.rados.gateway
ceph-authtool /etc/ceph/keyring.rados.gateway -n client.radosgw.gateway --gen-key
ceph-authtool -n client.radosgw.gateway --cap osd 'allow rwx' --cap mon 'allow r' /etc/ceph/keyring.rados.gateway
ceph -k /etc/ceph/ceph.keyring auth add client.radosgw.gateway -i /etc/ceph/keyring.rados.gateway

echo "Creating s3 user"
radosgw-admin user create --uid="ubuntu" --display-name="Ubuntu Ceph" > /tmp/radosgw.user

echo "Sleeping for a bit to allow ceph to get everything initialized"
sleep 20

echo "Starting rados gateway"
service radosgw start
