#!/usr/bin/python
#
# Copyright (C) 2010, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-server-iso-testing.
#
# ubuntu-server-iso-testing is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-server-iso-testing is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-server-iso-testing.  If not, see
# <http://www.gnu.org/licenses/>.
#

import logging
import os.path
import unittest
import subprocess
import multiprocessing

logging.basicConfig(level=logging.INFO)


class DefaultTest(unittest.TestCase):
    def testReadWrite(self):
        t_fh = open(os.path.join('/tmp', 'a'), 'w')
        self.assertNotEqual(t_fh, None)
        self.assertEqual(t_fh.write('a'), None)
        self.assertEqual(t_fh.close(), None)

    @unittest.skipUnless(multiprocessing.cpu_count() > 1,
                         "Only one CPU - irqbalance should not be running")
    def testIrqbalance(self):
        cmd = ["pgrep", "irqbalance"]
        logging.debug("Cmd: %s" % (cmd))
        output = subprocess.Popen(cmd, stdout=subprocess.PIPE).communicate()[0]
        logging.debug("Cmd output: %s", output)
        self.assertTrue(output.count('\n') > 0,
                        "irqbalance is not running")

    def testIrqbalanceInstalled(self):
        cmd = ["dpkg", "-l", "irqbalance"]
        logging.debug("Cmd: %s" % (cmd))
        output = subprocess.Popen(cmd, stdout=subprocess.PIPE).communicate()[0]
        logging.debug("Cmd output: %s", output)
        self.assertTrue(len(output.split()) > 1,
                        output)


if __name__ == '__main__':
    unittest.main()
