#!/usr/bin/python
#
# Copyright (C) 2010, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-server-iso-testing.
#
# ubuntu-server-iso-testing is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-server-iso-testing is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-server-iso-testing.  If not, see
# <http://www.gnu.org/licenses/>.
#


import logging
import subprocess
import unittest

logging.basicConfig(level=logging.INFO)


# Tables known to exist on a default install for Trusty and Vivid.
EXPECTED_TABLES = set([
    'columns_priv',
    'db',
    'event',
    'func',
    'general_log',
    'help_category',
    'help_keyword',
    'help_relation',
    'help_topic',
    'ndb_binlog_index',
    'plugin',
    'proc',
    'procs_priv',
    'proxies_priv',
    'servers',
    'slow_log',
    'tables_priv',
    'time_zone',
    'time_zone_leap_second',
    'time_zone_name',
    'time_zone_transition',
    'time_zone_transition_type',
    'user'])


class LampTest(unittest.TestCase):
    def testMysqlShowTables(self):
        cmd = ["mysql", "-e", "show tables",
               "--silent", "--silent", "mysql"]
        logging.debug("Cmd: %s" % (cmd))
        (output, stderr) = subprocess.Popen(
            cmd, stdout=subprocess.PIPE).communicate()

        self.assertEqual(stderr, None)
        logging.debug("Cmd output: %s" % (output))
        result = output.strip().split("\n")
        # Check that the output contains some default tables.
        self.assertTrue(EXPECTED_TABLES.issubset(set(result)))
        # Check for a minimum of 24 tables as the number might vary between
        # releases. See bug 1443987.
        self.assertGreaterEqual(len(result), 24)


if __name__ == '__main__':
    unittest.main()
