#!/usr/bin/python
#
# Copyright (C) 2010, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-server-iso-testing.
#
# ubuntu-server-iso-testing is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-server-iso-testing is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-server-iso-testing.  If not, see
# <http://www.gnu.org/licenses/>.
#


import email.mime.text
import logging
import mailbox
import os.path
import smtplib
import time
import unittest

logging.basicConfig(level=logging.DEBUG)


class MailServerTest(unittest.TestCase):
    def testSMTPServer(self):
        me = "testscript"
        you = "root"
        msg = email.mime.text.MIMEText("Test")
        msg['Subject'] = "Test email"
        msg['From'] = me
        msg['To'] = you

        logging.info("Creating an SMTP session")
        try:
            s = smtplib.SMTP('localhost', 25)
        except smtplib.SMTPException, e:
            logging.error("Failed to create SMTP session '%s'", e)
            self.fail("Failed to setup SMTP")

        logging.info("Creating an SMTP session")
        try:
            s.sendmail(me, [you], msg.as_string())
        except smtplib.SMTPException, e:
            logging.error("Failed to send email due to '%s'", e)
            self.fail("Failed to send email")

        s.quit()
        spool_file = '/var/mail/nobody'
        time.sleep(3)

        logging.info('Physically checking for the file')
        self.assertTrue(spool_file)
        mbox = mailbox.mbox(spool_file)

        logging.info('Check there is 1 message in the message box')
        self.assertEquals(len(mbox.keys()), 1, mbox)

    # Clean up
    def tearDown(self):
        if os.path.exists('/var/mail/nobody'):
            os.remove('/var/mail/nobody')

if __name__ == '__main__':
    unittest.main()
