#!/usr/bin/python
#
# Copyright (C) 2010, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-server-iso-testing.
#
# ubuntu-server-iso-testing is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-server-iso-testing is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-server-iso-testing.  If not, see
# <http://www.gnu.org/licenses/>.
#


import logging
import os.path
import unittest
import paramiko

logging.basicConfig(level=logging.INFO)

TEST_DATA = """
THIS IS A TEST OF SFTP FOR UBUNTU
"""


class OpenSSHAccessTest(unittest.TestCase):
    def testSSHaccess(self):
        # Login using SSH and run command to prove access works
        ssh = paramiko.SSHClient()
        ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        ssh.connect('localhost', username='utah', password='!ubuntu123')
        stdin, stdout, stderr = ssh.exec_command('whoami')
        result = stdout.read()
        self.assertTrue("utah" in result,
                        "Unable to execute command via SSH: %s" % result)
        ssh.close()

    def testSFTPaccess(self):
        # Login using SFTP and upload file
        ssh = paramiko.SSHClient()
        ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        ssh.connect('localhost', username='utah', password='!ubuntu123')
        sftp = ssh.open_sftp()
        w_file = sftp.file(os.path.join("/tmp", "sftp-test"), "w")
        w_file.write(TEST_DATA)
        w_file.close()
        r_file = sftp.file(os.path.join("/tmp", "sftp-test"), "r")
        data = r_file.read()
        self.assertTrue(TEST_DATA in data,
                        "Unable to retrieve data from server")
        ssh.close()

if __name__ == '__main__':
    unittest.main()
