#!/usr/bin/python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-server-iso-testing.
#
# ubuntu-server-iso-testing is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-server-iso-testing is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-server-iso-testing.  If not, see
# <http://www.gnu.org/licenses/>.
#


import logging
import subprocess
import unittest
import platform

logging.basicConfig(level=logging.INFO)


class VirtualHostTest(unittest.TestCase):
    def testUbuntuVirtServer(self):
        cmd = ["dpkg-query", "-W", "-f=${Package}", "ubuntu-virt-server"]
        logging.debug("Cmd: %s" % (cmd))
        output = subprocess.Popen(cmd,
                                  stdout=subprocess.PIPE).communicate()[0]
        logging.debug("Cmd output: %s" % (output))
        self.assertEqual("ubuntu-virt-server", output)

    @unittest.skipUnless(platform.machine() == "x86_64",
                         "Disabled on non-x86_64 platforms")
    def testKVMOK(self):
        cmd = ["kvm-ok"]
        logging.debug("Cmd: %s" % (cmd))
        self.assertTrue(subprocess.call(cmd) == 0, "KVM not OK")

    @unittest.skipUnless(platform.machine() == "x86_64",
                         "Disabled on non-x86_64 platforms")
    def testKVMEnabled(self):
        cmd = ["lsmod"]
        logging.debug("Cmd: %s" % (cmd))
        output = subprocess.Popen(cmd,
                                  stdout=subprocess.PIPE).communicate()[0]
        logging.debug("Cmd output: %s" % (output))
        self.assertTrue(("kvm_intel" in output) or
                        ("kvm_amd" in output), "kvm module not enabled")

if __name__ == '__main__':
    unittest.main()
